@@ -325,11 +325,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     mModelColumnManager->load();
 
     initializeImportExportPlugin(guiClient->actionCollection());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     QMetaObject::invokeMethod(this, &MainWidget::delayedInit, Qt::QueuedConnection);
-#else
-    QMetaObject::invokeMethod(this, "delayedInit", Qt::QueuedConnection);
-#endif
     updateQuickSearchText();
 }
 
@@ -515,7 +511,7 @@ void MainWidget::setupGui()
 {
     // the horizontal main layout
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     // Splitter 1 contains the two main parts of the GUI:
     //  - collection and item view splitter 2 on the left (see below)
@@ -556,7 +552,7 @@ void MainWidget::setupGui()
     mMainWidgetSplitter1->setChildrenCollapsible(false);
 
     QVBoxLayout *detailsPaneLayout = new QVBoxLayout(mDetailsPane);
-    detailsPaneLayout->setMargin(0);
+    detailsPaneLayout->setContentsMargins(0, 0, 0, 0);
 
     // the details view stack
     mDetailsViewStack = new QStackedWidget();
